@@ -33,8 +33,11 @@ for ( i=0, iLen=allSettings.length ; i<iLen ; i++ )
 	var s = allSettings[i];
 
 	/* Base check on table node */
-	if ( s.nTable == this || s.nTHead.parentNode == this || (s.nTFoot && s.nTFoot.parentNode == this) )
-	{
+	if (
+		s.nTable == this ||
+		(s.nTHead && s.nTHead.parentNode == this) ||
+		(s.nTFoot && s.nTFoot.parentNode == this)
+	) {
 		var bRetrieve = oInit.bRetrieve !== undefined ? oInit.bRetrieve : defaults.bRetrieve;
 		var bDestroy = oInit.bDestroy !== undefined ? oInit.bDestroy : defaults.bDestroy;
 
@@ -91,11 +94,7 @@ oSettings.oInstance = (_that.length===1) ? _that : $this.dataTable();
 
 // Backwards compatibility, before we apply all the defaults
 _fnCompatOpts( oInit );
-
-if ( oInit.oLanguage )
-{
-	_fnLanguageCompat( oInit.oLanguage );
-}
+_fnLanguageCompat( oInit.oLanguage );
 
 // If the length menu is given, but the init display length is not, use the length menu
 if ( oInit.aLengthMenu && ! oInit.iDisplayLength )
